@@ -240,7 +240,12 @@ class MyApp(wx.App):
                     if len(DTCCodes)==0:
                       wx.PostEvent(self._notify_window, DTCEvent(["","","No DTC codes (codes cleared)"]))
                     for i in range (0,len(DTCCodes)):
-                      wx.PostEvent(self._notify_window, DTCEvent([DTCCodes[i][1],DTCCodes[i][0],pcodes[DTCCodes[i][1]]]))   
+                      try:
+                         wx.PostEvent(self._notify_window, DTCEvent([DTCCodes[i][1],DTCCodes[i][0],pcodes[DTCCodes[i][1]]]))
+                      except:
+                         wx.PostEvent(self._notify_window, DTCEvent([DTCCodes[i][1],DTCCodes[i][0],"? UNKNOWN"]))
+                         pass
+
                 else:
                  pass 
             self.stop()
@@ -535,33 +540,32 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """Adaptet to work with n900 by m750
+        Text = """Adapted to work with n900 by m750
 Now work only with BT ELM OBD devices. 
 
 Note: pyOBD does not recognize all the 
 error codes, especially those personalized 
-by the cars factories. If the ECU sends 
-one unrecognized error, the program stops. 
+by the cars factories. 
 Eventually you can edit the file: 
   /home/opt/obd2_codes.py 
 and add that particular error code. 
 
 """
 
-        self.HelpAboutMaemoDlg = wx.MessageDialog(self.frame, Text, 'About n900',wx.OK | wx.ICON_INFORMATION)
+        self.HelpAboutMaemoDlg = wx.MessageDialog(self.frame, Text, 'About n900 adapting',wx.OK | wx.ICON_INFORMATION)
         self.HelpAboutMaemoDlg.ShowModal()
         self.HelpAboutMaemoDlg.Destroy()
 
-
-
     
     def OnHelpAbout(self,event): #todo about box
         Text = """PyOBD is an automotive OBD2 diagnosting application using ELM237 cable.
 (C) 2008-2009 SeCons Ltd.
 (C) 2004 Charles Donour Sizemore
 www.obdtester.com  www.secons.com
-
-PyOBD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; 
+PyOBD is free software; you can 
+redistribute it and/or modify it under the 
+terms of the GNU General Public License 
+as published by the Free SW Foundation; 
 either version 2 of the License, or (at your option) any later version.   
 
 """
@@ -583,7 +587,7 @@ either version 2 of the License, or (at your option) any later version.
         #sizer.Fit(HelpAboutDlg)
         #HelpAboutDlg.ShowModal()
         
-        self.HelpAboutDlg = wx.MessageDialog(self.frame, Text, 'About',wx.OK | wx.ICON_INFORMATION)
+        self.HelpAboutDlg = wx.MessageDialog(self.frame, Text, 'About PyOBD' ,wx.OK | wx.ICON_INFORMATION)
         self.HelpAboutDlg.ShowModal()
         self.HelpAboutDlg.Destroy()
         
